Name:		e2guardian
Version:	5.3.4
%define 	subrel 1
Release:	%mkrel 1
Summary:	Open Source web content filter
License:	GPLv2+
Group:		System/Servers
URL:		http://e2guardian.org/cms/
Source0:	https://github.com/e2guardian/e2guardian/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	e2guardian.service
Patch0:		e2guardian-mga_conf.patch

# 
# Security patches
# P100 -> ...
#
# CVE-2021-44273
Patch100:	eae46a7e2a57103aadca903c4a24cca94dc502a2.patch

BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libpcreposix)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	libesmtp-devel

Requires(post):	rpm-helper
Requires(pre):	rpm-helper
Requires(preun): rpm-helper
Requires(postun): rpm-helper

Recommends:	webproxy

Obsoletes:	dansguardian < 2.12.0.3-9

%description
e2guardian is an Open Source web content filter, It filters the actual
content of pages based on many methods including phrase matching, request
header and URL filtering, etc. It does not purely filter based on a banned
list of sites.
e2guardian is a content filtering proxy that works in conjunction with
another caching proxy such as Squid or Oops.
e2guardian is a fork of DansGuardian and the maintainers fully acknowledge
the work carried out by and the copyright of Daniel Baron and other
contributors to the Dansguardian project.

%prep
%setup -q
%autopatch -p1

# fix permission
chmod 0644 doc/* AUTHORS ChangeLog COPYING

%build
NOCONFIGURE=1 ./autogen.sh

%configure \
	--localstatedir=%{_var}/lib \
	--disable-silent-rules \
	--enable-pcre=yes \
	--enable-clamd=yes \
	--enable-icap=yes \
	--enable-kavd=no \
	--enable-commandline=yes \
	--enable-ntlm=yes \
	--enable-email=yes \
	--enable-orig-ip=yes \
	--enable-sslmitm=yes \
	--with-proxyuser=%{name} \
	--with-proxygroup=%{name} \
	--with-logdir=%{_var}/log/%{name} \
	--with-piddir=%{_rundir} \
	--with-sysconfsubdir=%{name}

%make_build

%install
%make_install

# systemd service
install -Dpm 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

# access log file
install -d %{buildroot}%{_var}/log/%{name}
touch %{buildroot}%{_var}/log/%{name}/access.log

install -d %{buildroot}%{_var}/lib/%{name}/tmp

# cgi-script
install -d %{buildroot}%{_var}/www/cgi-bin
install -m 0755 data/e2guardian.pl %{buildroot}%{_var}/www/cgi-bin/

# make sure this file is present
echo "localhost" >> %{buildroot}%{_sysconfdir}/%{name}/lists/exceptionfileurllist

# construct file lists
find %{buildroot}%{_sysconfdir}/%{name} -type d | \
    sed -e "s|%{buildroot}||" | sed -e 's/^/%attr(0755,root,root) %dir /' > %{name}.filelist

find %{buildroot}%{_sysconfdir}/%{name} -type f | grep -v "\.orig" | \
    sed -e "s|%{buildroot}||" | sed -e 's/^/%attr(0644,root,root) %config(noreplace) /' >> %{name}.filelist

# logrotate file
install -d %{buildroot}%{_sysconfdir}/logrotate.d
cat << EOF > %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
/var/log/%{name}/access.log {
    create 644 %{name} %{name}
    rotate 5
    weekly
    sharedscripts
    prerotate
	service %{name} stop
    endscript
    postrotate
	service %{name} start
    endscript
}
EOF

# README.urpmi Mageia file
cat > README.urpmi << EOF
Make sure to change your /etc/%{name}/%{name}.conf to reflect your own settings.
Special attention must be given to the port that the proxy server is listening to,
the port that %{name} will listen to and to the web url to the %{name}.pl cgi-script.

Author: Daniel Barron
daniel@jadeb.com
EOF

# cleanup
rm -rf %{buildroot}%{_datadir}/%{name}/scripts
rm -rf %{buildroot}%{_datadir}/doc/e2guardian*

%pre
%_pre_useradd %{name} /var/lib/%{name} /bin/false

%preun
%_preun_service %{name}
if [ $1 = 0 ] ; then
    rm -f /var/log/%{name}/*
fi

%post
%create_ghostfile /var/log/%{name}/access.log %{name} %{name} 644
%_post_service %{name}

%postun
%_postun_userdel %{name}

%files -f %{name}.filelist
%doc AUTHORS ChangeLog README.md README.urpmi
%doc doc/{AuthPlugins,ContentScanners,DownloadManagers}
%doc doc/{FAQ,FAQ.html,Plugins}
%license COPYING
%{_sbindir}/%{name}
%{_datadir}/%{name}/
%{_unitdir}/%{name}.service
%{_mandir}/man8/%{name}.8*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(0755,root,root) %{_var}/www/cgi-bin/%{name}.pl
%dir %attr(0755,%{name},%{name}) %{_var}/log/%{name}
%dir %attr(0755,%{name},%{name}) %{_var}/lib/%{name}
%dir %attr(0755,%{name},%{name}) %{_var}/lib/%{name}/tmp
%ghost %attr(0644,%{name},%{name}) %{_var}/log/%{name}/access.log


%changelog
* Sun Dec 26 2021 neoclust <neoclust> 5.3.4-1.1.mga8
+ Revision: 1764090
- Add P100: Fixes CVE-2021-44273 (mga#29811)

* Mon Feb 17 2020 daviddavid <daviddavid> 5.3.4-1.mga8
+ Revision: 1536910
- new version: 5.3.4

* Sat Feb 15 2020 umeabot <umeabot> 5.3.3-2.mga8
+ Revision: 1527995
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Aug 03 2019 daviddavid <daviddavid> 5.3.3-1.mga8
+ Revision: 1427011
- new version: 5.3.3

* Mon Mar 18 2019 daviddavid <daviddavid> 5.3.2-2.mga7
+ Revision: 1378601
- finally do not recommend e2guardian-children-blacklists

* Mon Mar 18 2019 daviddavid <daviddavid> 5.3.2-1.mga7
+ Revision: 1378563
- new version: 5.3.2
- now time to obsolete dead dansguardian project

* Tue Feb 19 2019 daviddavid <daviddavid> 5.3.1-1.mga7
+ Revision: 1368394
- new version: 5.3.1

* Wed Oct 31 2018 daviddavid <daviddavid> 5.2.2-1.mga7
+ Revision: 1326891
- new version: 5.2.2

* Thu Aug 30 2018 daviddavid <daviddavid> 5.2.0-1.mga7
+ Revision: 1255700
- new version: 5.2.0

* Sat Aug 18 2018 daviddavid <daviddavid> 5.1.1-1.mga7
+ Revision: 1252518
- new version: 5.1.1
- rediff mga_conf patch

* Mon May 21 2018 daviddavid <daviddavid> 4.1.5-1.mga7
+ Revision: 1231042
- new version: 4.1.5
- remove merged upstream patch
- compile now against openssl >= 1.1

* Fri Feb 16 2018 daviddavid <daviddavid> 4.1.4-1.mga7
+ Revision: 1201667
- new version: 4.1.4

* Fri Feb 16 2018 daviddavid <daviddavid> 4.1.2-1.mga7
+ Revision: 1201662
- add patch to honor user CXXFLAGS thus fixing empty debugsourcefiles.list
- new version: 4.1.2
- update e2guardian-mga_conf patch

* Sat Feb 18 2017 daviddavid <daviddavid> 3.5.0-1.mga6
+ Revision: 1086671
- new version: 3.5.0
- enable sslmitm support

* Sat Jul 09 2016 daviddavid <daviddavid> 3.4.0.3-1.mga6
+ Revision: 1039934
- initial package e2guardian

